@@ -1,14 +1,3 @@
-## THIS FILE NEEDS THOROUGH REVISION DUE TO THE INTRODUCTION OF
-## FORWARD/BACKWARD WARPING !!!
-
-## Paril 1 :-), 2011 (RW)
-## First working version of predict.ptw.
-
-## Eventually this function should also allow the prediction with a
-## different set of warping coefficients, but we'll leave that for now.
-## The way to do it is to create a ptw object with the try=TRUE option
-## and THEN do the prediction.
-
 predict.ptw <- function(object, newdata, 
                         what = c("response", "time"),
                         RTref = NULL, ...)
@@ -39,13 +28,26 @@ predict.ptw <- function(object, newdata,
            }
 
            ## do the warping
-           t(sapply(1:nrow(newdata),
-                    function(i) ##interpol(WF[i,], newdata[i,])))
-                      approx(newdata[i,], NULL, WF[i,])$y))
+           if (object$mode == "backward") {
+             t(sapply(1:nrow(newdata),
+                      function(i)
+                        approx(x = 1:ncol(newdata), y = newdata[i,],
+                               xout = WF[i,])$y))
+           } else { # object$mode == "forward"
+             t(sapply(1:nrow(newdata),
+                      function(i)
+                        approx(x = WF[i,], y = newdata[i,],
+                               xout = 1:ncol(newdata))$y))
+           }
          },
          time = {
-           correctedTime <- 
-             -sweep(object$warp.fun, 2, 2*(1:ncol(object$ref)), FUN = "-")
+           correctedTime <-
+             switch(object$mode,
+                    backward =
+                      -sweep(object$warp.fun, 2,
+                             2*(1:ncol(object$ref)), FUN = "-"),
+                    object$warp.fun)
+           
            if (is.null(RTref)){
              if (is.null(colnames(object$ref))) {
                RTref <- 1:ncol(object$ref)
@@ -58,10 +60,6 @@ predict.ptw <- function(object, newdata,
              newdata <- RTref
              newdataIndices <- 1:length(RTref)
            } else {
-             ## the round statement is necessary to explicitly convert
-             ## newdataIndices to an integer value: otherwise the
-             ## interpol function later will give back an incorrect
-             ## value. Why???             
              newdataIndices <-
                  round((newdata - min(RTref)) * (length(RTref) - 1) /
                        diff(range(RTref)) + 1)
@@ -70,7 +68,5 @@ predict.ptw <- function(object, newdata,
            t(sapply(1:nrow(correctedTime),
                     function(i)
                       approx(RTref, NULL, correctedTime[i, newdataIndices])$y))
-##                    interpol(correctedTime[i, newdataIndices],
-##                             RTref)))
          })
 }
